Error

Enum Error 

pub enum Error {
    RegisterUnchanged,
    DmaError(DmaError),
    I2cError(I2cError),
    UsartError(UsartError),
    TimerError(TimerError),
    FlashError(FlashError),
    PolynomialError(PolynomialError),
    SpiError(SpiError),
    RtcError(RtcError),
    RccError(RccError),
}
Collection of all errors that can occur.

Variants



RegisterUnchanged

Occurs when an expected change of a register does happen in time.

This is returned when a bounded loop exceeds its alotted iteration count.



DmaError(DmaError)

Direct Memory Access (DMA) error



I2cError(I2cError)



UsartError(UsartError)



TimerError(TimerError)



FlashError(FlashError)



PolynomialError(PolynomialError)

CRC



SpiError(SpiError)

SPI errors.



RtcError(RtcError)

Clock errors.



RccError(RccError)